@@ -2,18 +2,18 @@
 #  include "config.h"
 #endif
 /****************************************************************************
-** Meta object code from reading C++ file 'ToolBar.h'
+** Meta object code from reading C++ file 'moc-ToolBar.h'
 **
 ** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/graphics/ToolBar.h"
+#include "libgui/graphics/moc-ToolBar.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
-#error "The header file 'ToolBar.h' doesn't include <QObject>."
+#error "The header file 'moc-ToolBar.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 67
 #error "This file was generated using the moc from 5.9.4. It"
 #error "cannot be used with the include files from this version of Qt."
@@ -23,27 +23,27 @@
 QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
-struct qt_meta_stringdata_QtHandles__ToolBar_t {
+struct qt_meta_stringdata_octave__ToolBar_t {
     QByteArrayData data[3];
-    char stringdata0[30];
+    char stringdata0[27];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
-    qptrdiff(offsetof(qt_meta_stringdata_QtHandles__ToolBar_t, stringdata0) + ofs \
+    qptrdiff(offsetof(qt_meta_stringdata_octave__ToolBar_t, stringdata0) + ofs \
         - idx * sizeof(QByteArrayData)) \
     )
-static const qt_meta_stringdata_QtHandles__ToolBar_t qt_meta_stringdata_QtHandles__ToolBar = {
+static const qt_meta_stringdata_octave__ToolBar_t qt_meta_stringdata_octave__ToolBar = {
     {
-QT_MOC_LITERAL(0, 0, 18), // "QtHandles::ToolBar"
-QT_MOC_LITERAL(1, 19, 9), // "hideEmpty"
-QT_MOC_LITERAL(2, 29, 0) // ""
+QT_MOC_LITERAL(0, 0, 15), // "octave::ToolBar"
+QT_MOC_LITERAL(1, 16, 9), // "hideEmpty"
+QT_MOC_LITERAL(2, 26, 0) // ""
 
     },
-    "QtHandles::ToolBar\0hideEmpty\0"
+    "octave::ToolBar\0hideEmpty\0"
 };
 #undef QT_MOC_LITERAL
 
-static const uint qt_meta_data_QtHandles__ToolBar[] = {
+static const uint qt_meta_data_octave__ToolBar[] = {
 
  // content:
        7,       // revision
@@ -65,7 +65,7 @@ static const uint qt_meta_data_QtHandles__ToolBar[] = {
        0        // eod
 };
 
-void QtHandles::ToolBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
+void octave::ToolBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
 {
     if (_c == QMetaObject::InvokeMetaMethod) {
         ToolBar *_t = static_cast<ToolBar *>(_o);
@@ -78,26 +78,26 @@ void QtHandles::ToolBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, i
     Q_UNUSED(_a);
 }
 
-const QMetaObject QtHandles::ToolBar::staticMetaObject = {
-    { &Object::staticMetaObject, qt_meta_stringdata_QtHandles__ToolBar.data,
-      qt_meta_data_QtHandles__ToolBar,  qt_static_metacall, nullptr, nullptr}
+const QMetaObject octave::ToolBar::staticMetaObject = {
+    { &Object::staticMetaObject, qt_meta_stringdata_octave__ToolBar.data,
+      qt_meta_data_octave__ToolBar,  qt_static_metacall, nullptr, nullptr}
 };
 
 
-const QMetaObject *QtHandles::ToolBar::metaObject() const
+const QMetaObject *octave::ToolBar::metaObject() const
 {
     return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
 }
 
-void *QtHandles::ToolBar::qt_metacast(const char *_clname)
+void *octave::ToolBar::qt_metacast(const char *_clname)
 {
     if (!_clname) return nullptr;
-    if (!strcmp(_clname, qt_meta_stringdata_QtHandles__ToolBar.stringdata0))
+    if (!strcmp(_clname, qt_meta_stringdata_octave__ToolBar.stringdata0))
         return static_cast<void*>(this);
     return Object::qt_metacast(_clname);
 }
 
-int QtHandles::ToolBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
+int octave::ToolBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
 {
     _id = Object::qt_metacall(_c, _id, _a);
     if (_id < 0)
