@@ -2,18 +2,18 @@
 #  include "config.h"
 #endif
 /****************************************************************************
-** Meta object code from reading C++ file 'QTerminal.h'
+** Meta object code from reading C++ file 'moc-QTerminal.h'
 **
 ** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/pub/devel/octave/octave-6.4.0-1.i686/src/octave-6.4.0/libgui/qterminal/libqterminal/QTerminal.h"
+#include "libgui/qterminal/libqterminal/moc-QTerminal.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
-#error "The header file 'QTerminal.h' doesn't include <QObject>."
+#error "The header file 'moc-QTerminal.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 67
 #error "This file was generated using the moc from 5.9.4. It"
 #error "cannot be used with the include files from this version of Qt."
@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_QTerminal_t {
-    QByteArrayData data[25];
-    char stringdata0[410];
+    QByteArrayData data[27];
+    char stringdata0[482];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -41,36 +41,41 @@ QT_MOC_LITERAL(3, 33, 16), // "interrupt_signal"
 QT_MOC_LITERAL(4, 50, 18), // "edit_mfile_request"
 QT_MOC_LITERAL(5, 69, 15), // "show_doc_signal"
 QT_MOC_LITERAL(6, 85, 34), // "execute_command_in_terminal_s..."
-QT_MOC_LITERAL(7, 120, 13), // "copyClipboard"
-QT_MOC_LITERAL(8, 134, 14), // "pasteClipboard"
-QT_MOC_LITERAL(9, 149, 9), // "selectAll"
-QT_MOC_LITERAL(10, 159, 32), // "handleCustomContextMenuRequested"
-QT_MOC_LITERAL(11, 192, 2), // "at"
-QT_MOC_LITERAL(12, 195, 15), // "notice_settings"
-QT_MOC_LITERAL(13, 211, 19), // "const gui_settings*"
-QT_MOC_LITERAL(14, 231, 8), // "settings"
-QT_MOC_LITERAL(15, 240, 18), // "init_terminal_size"
-QT_MOC_LITERAL(16, 259, 18), // "terminal_interrupt"
-QT_MOC_LITERAL(17, 278, 20), // "set_global_shortcuts"
-QT_MOC_LITERAL(18, 299, 9), // "focus_out"
-QT_MOC_LITERAL(19, 309, 13), // "run_selection"
-QT_MOC_LITERAL(20, 323, 9), // "edit_file"
-QT_MOC_LITERAL(21, 333, 13), // "edit_selected"
-QT_MOC_LITERAL(22, 347, 18), // "help_on_expression"
-QT_MOC_LITERAL(23, 366, 17), // "doc_on_expression"
-QT_MOC_LITERAL(24, 384, 25) // "handle_visibility_changed"
+QT_MOC_LITERAL(7, 120, 25), // "request_edit_mfile_signal"
+QT_MOC_LITERAL(8, 146, 24), // "request_open_file_signal"
+QT_MOC_LITERAL(9, 171, 22), // "set_screen_size_signal"
+QT_MOC_LITERAL(10, 194, 28), // "clear_command_window_request"
+QT_MOC_LITERAL(11, 223, 13), // "copyClipboard"
+QT_MOC_LITERAL(12, 237, 14), // "pasteClipboard"
+QT_MOC_LITERAL(13, 252, 9), // "selectAll"
+QT_MOC_LITERAL(14, 262, 32), // "handleCustomContextMenuRequested"
+QT_MOC_LITERAL(15, 295, 2), // "at"
+QT_MOC_LITERAL(16, 298, 15), // "notice_settings"
+QT_MOC_LITERAL(17, 314, 19), // "const gui_settings*"
+QT_MOC_LITERAL(18, 334, 8), // "settings"
+QT_MOC_LITERAL(19, 343, 18), // "init_terminal_size"
+QT_MOC_LITERAL(20, 362, 18), // "terminal_interrupt"
+QT_MOC_LITERAL(21, 381, 13), // "run_selection"
+QT_MOC_LITERAL(22, 395, 9), // "edit_file"
+QT_MOC_LITERAL(23, 405, 13), // "edit_selected"
+QT_MOC_LITERAL(24, 419, 18), // "help_on_expression"
+QT_MOC_LITERAL(25, 438, 17), // "doc_on_expression"
+QT_MOC_LITERAL(26, 456, 25) // "handle_visibility_changed"
 
     },
     "QTerminal\0report_status_message\0\0"
     "interrupt_signal\0edit_mfile_request\0"
     "show_doc_signal\0execute_command_in_terminal_signal\0"
-    "copyClipboard\0pasteClipboard\0selectAll\0"
+    "request_edit_mfile_signal\0"
+    "request_open_file_signal\0"
+    "set_screen_size_signal\0"
+    "clear_command_window_request\0copyClipboard\0"
+    "pasteClipboard\0selectAll\0"
     "handleCustomContextMenuRequested\0at\0"
     "notice_settings\0const gui_settings*\0"
     "settings\0init_terminal_size\0"
-    "terminal_interrupt\0set_global_shortcuts\0"
-    "focus_out\0run_selection\0edit_file\0"
-    "edit_selected\0help_on_expression\0"
+    "terminal_interrupt\0run_selection\0"
+    "edit_file\0edit_selected\0help_on_expression\0"
     "doc_on_expression\0handle_visibility_changed"
 };
 #undef QT_MOC_LITERAL
@@ -81,35 +86,38 @@ static const uint qt_meta_data_QTerminal[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-      19,   14, // methods
+      22,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
        0,       // flags
-       5,       // signalCount
+       9,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    1,  109,    2, 0x06 /* Public */,
-       3,    0,  112,    2, 0x06 /* Public */,
-       4,    2,  113,    2, 0x06 /* Public */,
-       5,    1,  118,    2, 0x06 /* Public */,
-       6,    1,  121,    2, 0x06 /* Public */,
+       1,    1,  124,    2, 0x06 /* Public */,
+       3,    0,  127,    2, 0x06 /* Public */,
+       4,    2,  128,    2, 0x06 /* Public */,
+       5,    1,  133,    2, 0x06 /* Public */,
+       6,    1,  136,    2, 0x06 /* Public */,
+       7,    2,  139,    2, 0x06 /* Public */,
+       8,    3,  144,    2, 0x06 /* Public */,
+       9,    2,  151,    2, 0x06 /* Public */,
+      10,    0,  156,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-       7,    0,  124,    2, 0x0a /* Public */,
-       8,    0,  125,    2, 0x0a /* Public */,
-       9,    0,  126,    2, 0x0a /* Public */,
-      10,    1,  127,    2, 0x0a /* Public */,
-      12,    1,  130,    2, 0x0a /* Public */,
-      15,    0,  133,    2, 0x0a /* Public */,
-      16,    0,  134,    2, 0x0a /* Public */,
-      17,    1,  135,    2, 0x0a /* Public */,
-      19,    0,  138,    2, 0x0a /* Public */,
-      20,    0,  139,    2, 0x0a /* Public */,
-      21,    0,  140,    2, 0x0a /* Public */,
-      22,    0,  141,    2, 0x0a /* Public */,
-      23,    0,  142,    2, 0x0a /* Public */,
-      24,    1,  143,    2, 0x0a /* Public */,
+      11,    0,  157,    2, 0x0a /* Public */,
+      12,    0,  158,    2, 0x0a /* Public */,
+      13,    0,  159,    2, 0x0a /* Public */,
+      14,    1,  160,    2, 0x0a /* Public */,
+      16,    1,  163,    2, 0x0a /* Public */,
+      19,    0,  166,    2, 0x0a /* Public */,
+      20,    0,  167,    2, 0x0a /* Public */,
+      21,    0,  168,    2, 0x0a /* Public */,
+      22,    0,  169,    2, 0x0a /* Public */,
+      23,    0,  170,    2, 0x0a /* Public */,
+      24,    0,  171,    2, 0x0a /* Public */,
+      25,    0,  172,    2, 0x0a /* Public */,
+      26,    1,  173,    2, 0x0a /* Public */,
 
  // signals: parameters
     QMetaType::Void, QMetaType::QString,    2,
@@ -117,16 +125,19 @@ static const uint qt_meta_data_QTerminal[] = {
     QMetaType::Void, QMetaType::QString, QMetaType::Int,    2,    2,
     QMetaType::Void, QMetaType::QString,    2,
     QMetaType::Void, QMetaType::QString,    2,
+    QMetaType::Void, QMetaType::QString, QMetaType::Int,    2,    2,
+    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::Int,    2,    2,    2,
+    QMetaType::Void, QMetaType::Int, QMetaType::Int,    2,    2,
+    QMetaType::Void,
 
  // slots: parameters
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::QPoint,   11,
-    QMetaType::Void, 0x80000000 | 13,   14,
+    QMetaType::Void, QMetaType::QPoint,   15,
+    QMetaType::Void, 0x80000000 | 17,   18,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::Bool,   18,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
@@ -148,20 +159,23 @@ void QTerminal::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, v
         case 2: _t->edit_mfile_request((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
         case 3: _t->show_doc_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
         case 4: _t->execute_command_in_terminal_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 5: _t->copyClipboard(); break;
-        case 6: _t->pasteClipboard(); break;
-        case 7: _t->selectAll(); break;
-        case 8: _t->handleCustomContextMenuRequested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
-        case 9: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
-        case 10: _t->init_terminal_size(); break;
-        case 11: _t->terminal_interrupt(); break;
-        case 12: _t->set_global_shortcuts((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 13: _t->run_selection(); break;
-        case 14: _t->edit_file(); break;
-        case 15: _t->edit_selected(); break;
-        case 16: _t->help_on_expression(); break;
-        case 17: _t->doc_on_expression(); break;
-        case 18: _t->handle_visibility_changed((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 5: _t->request_edit_mfile_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
+        case 6: _t->request_open_file_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
+        case 7: _t->set_screen_size_signal((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
+        case 8: _t->clear_command_window_request(); break;
+        case 9: _t->copyClipboard(); break;
+        case 10: _t->pasteClipboard(); break;
+        case 11: _t->selectAll(); break;
+        case 12: _t->handleCustomContextMenuRequested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
+        case 13: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
+        case 14: _t->init_terminal_size(); break;
+        case 15: _t->terminal_interrupt(); break;
+        case 16: _t->run_selection(); break;
+        case 17: _t->edit_file(); break;
+        case 18: _t->edit_selected(); break;
+        case 19: _t->help_on_expression(); break;
+        case 20: _t->doc_on_expression(); break;
+        case 21: _t->handle_visibility_changed((*reinterpret_cast< bool(*)>(_a[1]))); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -201,6 +215,34 @@ void QTerminal::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, v
                 return;
             }
         }
+        {
+            typedef void (QTerminal::*_t)(const QString & , int );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QTerminal::request_edit_mfile_signal)) {
+                *result = 5;
+                return;
+            }
+        }
+        {
+            typedef void (QTerminal::*_t)(const QString & , const QString & , int );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QTerminal::request_open_file_signal)) {
+                *result = 6;
+                return;
+            }
+        }
+        {
+            typedef void (QTerminal::*_t)(int , int );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QTerminal::set_screen_size_signal)) {
+                *result = 7;
+                return;
+            }
+        }
+        {
+            typedef void (QTerminal::*_t)();
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QTerminal::clear_command_window_request)) {
+                *result = 8;
+                return;
+            }
+        }
     }
 }
 
@@ -229,13 +271,13 @@ int QTerminal::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 19)
+        if (_id < 22)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 19;
+        _id -= 22;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 19)
+        if (_id < 22)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 19;
+        _id -= 22;
     }
     return _id;
 }
@@ -273,5 +315,32 @@ void QTerminal::execute_command_in_terminal_signal(const QString & _t1)
     void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
     QMetaObject::activate(this, &staticMetaObject, 4, _a);
 }
+
+// SIGNAL 5
+void QTerminal::request_edit_mfile_signal(const QString & _t1, int _t2)
+{
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
+    QMetaObject::activate(this, &staticMetaObject, 5, _a);
+}
+
+// SIGNAL 6
+void QTerminal::request_open_file_signal(const QString & _t1, const QString & _t2, int _t3)
+{
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
+    QMetaObject::activate(this, &staticMetaObject, 6, _a);
+}
+
+// SIGNAL 7
+void QTerminal::set_screen_size_signal(int _t1, int _t2)
+{
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
+    QMetaObject::activate(this, &staticMetaObject, 7, _a);
+}
+
+// SIGNAL 8
+void QTerminal::clear_command_window_request()
+{
+    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
+}
 QT_WARNING_POP
 QT_END_MOC_NAMESPACE
