@@ -2,18 +2,18 @@
 #  include "config.h"
 #endif
 /****************************************************************************
-** Meta object code from reading C++ file 'documentation-dock-widget.h'
+** Meta object code from reading C++ file 'moc-documentation-dock-widget.h'
 **
 ** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/src/documentation-dock-widget.h"
+#include "libgui/src/moc-documentation-dock-widget.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
-#error "The header file 'documentation-dock-widget.h' doesn't include <QObject>."
+#error "The header file 'moc-documentation-dock-widget.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 67
 #error "This file was generated using the moc from 5.9.4. It"
 #error "cannot be used with the include files from this version of Qt."
@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_octave__documentation_dock_widget_t {
-    QByteArrayData data[12];
-    char stringdata0[155];
+    QByteArrayData data[13];
+    char stringdata0[172];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -37,22 +37,23 @@ static const qt_meta_stringdata_octave__documentation_dock_widget_t qt_meta_stri
 QT_MOC_LITERAL(0, 0, 33), // "octave::documentation_dock_wi..."
 QT_MOC_LITERAL(1, 34, 15), // "notice_settings"
 QT_MOC_LITERAL(2, 50, 0), // ""
-QT_MOC_LITERAL(3, 51, 16), // "const QSettings*"
-QT_MOC_LITERAL(4, 68, 8), // "settings"
-QT_MOC_LITERAL(5, 77, 13), // "copyClipboard"
-QT_MOC_LITERAL(6, 91, 14), // "pasteClipboard"
-QT_MOC_LITERAL(7, 106, 9), // "selectAll"
-QT_MOC_LITERAL(8, 116, 7), // "showDoc"
-QT_MOC_LITERAL(9, 124, 4), // "name"
-QT_MOC_LITERAL(10, 129, 11), // "registerDoc"
-QT_MOC_LITERAL(11, 141, 13) // "unregisterDoc"
+QT_MOC_LITERAL(3, 51, 19), // "const gui_settings*"
+QT_MOC_LITERAL(4, 71, 8), // "settings"
+QT_MOC_LITERAL(5, 80, 13), // "save_settings"
+QT_MOC_LITERAL(6, 94, 13), // "copyClipboard"
+QT_MOC_LITERAL(7, 108, 14), // "pasteClipboard"
+QT_MOC_LITERAL(8, 123, 9), // "selectAll"
+QT_MOC_LITERAL(9, 133, 7), // "showDoc"
+QT_MOC_LITERAL(10, 141, 4), // "name"
+QT_MOC_LITERAL(11, 146, 11), // "registerDoc"
+QT_MOC_LITERAL(12, 158, 13) // "unregisterDoc"
 
     },
     "octave::documentation_dock_widget\0"
-    "notice_settings\0\0const QSettings*\0"
-    "settings\0copyClipboard\0pasteClipboard\0"
-    "selectAll\0showDoc\0name\0registerDoc\0"
-    "unregisterDoc"
+    "notice_settings\0\0const gui_settings*\0"
+    "settings\0save_settings\0copyClipboard\0"
+    "pasteClipboard\0selectAll\0showDoc\0name\0"
+    "registerDoc\0unregisterDoc"
 };
 #undef QT_MOC_LITERAL
 
@@ -62,7 +63,7 @@ static const uint qt_meta_data_octave__documentation_dock_widget[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-       7,   14, // methods
+       8,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
@@ -70,22 +71,24 @@ static const uint qt_meta_data_octave__documentation_dock_widget[] = {
        0,       // signalCount
 
  // slots: name, argc, parameters, tag, flags
-       1,    1,   49,    2, 0x0a /* Public */,
-       5,    0,   52,    2, 0x09 /* Protected */,
-       6,    0,   53,    2, 0x09 /* Protected */,
-       7,    0,   54,    2, 0x09 /* Protected */,
-       8,    1,   55,    2, 0x09 /* Protected */,
-      10,    1,   58,    2, 0x09 /* Protected */,
-      11,    1,   61,    2, 0x09 /* Protected */,
+       1,    1,   54,    2, 0x0a /* Public */,
+       5,    0,   57,    2, 0x0a /* Public */,
+       6,    0,   58,    2, 0x0a /* Public */,
+       7,    0,   59,    2, 0x0a /* Public */,
+       8,    0,   60,    2, 0x0a /* Public */,
+       9,    1,   61,    2, 0x0a /* Public */,
+      11,    1,   64,    2, 0x0a /* Public */,
+      12,    1,   67,    2, 0x0a /* Public */,
 
  // slots: parameters
     QMetaType::Void, 0x80000000 | 3,    4,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::QString,    9,
-    QMetaType::Void, QMetaType::QString,    9,
-    QMetaType::Void, QMetaType::QString,    9,
+    QMetaType::Void,
+    QMetaType::Void, QMetaType::QString,   10,
+    QMetaType::Void, QMetaType::QString,   10,
+    QMetaType::Void, QMetaType::QString,   10,
 
        0        // eod
 };
@@ -96,13 +99,14 @@ void octave::documentation_dock_widget::qt_static_metacall(QObject *_o, QMetaObj
         documentation_dock_widget *_t = static_cast<documentation_dock_widget *>(_o);
         Q_UNUSED(_t)
         switch (_id) {
-        case 0: _t->notice_settings((*reinterpret_cast< const QSettings*(*)>(_a[1]))); break;
-        case 1: _t->copyClipboard(); break;
-        case 2: _t->pasteClipboard(); break;
-        case 3: _t->selectAll(); break;
-        case 4: _t->showDoc((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 5: _t->registerDoc((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 6: _t->unregisterDoc((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 0: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
+        case 1: _t->save_settings(); break;
+        case 2: _t->copyClipboard(); break;
+        case 3: _t->pasteClipboard(); break;
+        case 4: _t->selectAll(); break;
+        case 5: _t->showDoc((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 6: _t->registerDoc((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 7: _t->unregisterDoc((*reinterpret_cast< const QString(*)>(_a[1]))); break;
         default: ;
         }
     }
@@ -133,13 +137,13 @@ int octave::documentation_dock_widget::qt_metacall(QMetaObject::Call _c, int _id
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 7)
+        if (_id < 8)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 7;
+        _id -= 8;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 7)
+        if (_id < 8)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 7;
+        _id -= 8;
     }
     return _id;
 }
