@@ -2,18 +2,18 @@
 #  include "config.h"
 #endif
 /****************************************************************************
-** Meta object code from reading C++ file 'files-dock-widget.h'
+** Meta object code from reading C++ file 'moc-files-dock-widget.h'
 **
 ** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/src/files-dock-widget.h"
+#include "libgui/src/moc-files-dock-widget.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
-#error "The header file 'files-dock-widget.h' doesn't include <QObject>."
+#error "The header file 'moc-files-dock-widget.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 67
 #error "This file was generated using the moc from 5.9.4. It"
 #error "cannot be used with the include files from this version of Qt."
@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_octave__files_dock_widget_t {
-    QByteArrayData data[54];
-    char stringdata0[917];
+    QByteArrayData data[62];
+    char stringdata0[1073];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -51,43 +51,51 @@ QT_MOC_LITERAL(13, 169, 18), // "file_remove_signal"
 QT_MOC_LITERAL(14, 188, 8), // "old_name"
 QT_MOC_LITERAL(15, 197, 8), // "new_name"
 QT_MOC_LITERAL(16, 206, 19), // "file_renamed_signal"
-QT_MOC_LITERAL(17, 226, 19), // "item_double_clicked"
-QT_MOC_LITERAL(18, 246, 5), // "index"
-QT_MOC_LITERAL(19, 252, 19), // "change_directory_up"
-QT_MOC_LITERAL(20, 272, 24), // "do_sync_octave_directory"
-QT_MOC_LITERAL(21, 297, 25), // "do_sync_browser_directory"
-QT_MOC_LITERAL(22, 323, 21), // "set_current_directory"
-QT_MOC_LITERAL(23, 345, 26), // "accept_directory_line_edit"
-QT_MOC_LITERAL(24, 372, 23), // "update_octave_directory"
-QT_MOC_LITERAL(25, 396, 15), // "notice_settings"
-QT_MOC_LITERAL(26, 412, 16), // "const QSettings*"
-QT_MOC_LITERAL(27, 429, 8), // "settings"
-QT_MOC_LITERAL(28, 438, 13), // "save_settings"
-QT_MOC_LITERAL(29, 452, 27), // "headercontextmenu_requested"
-QT_MOC_LITERAL(30, 480, 3), // "pos"
-QT_MOC_LITERAL(31, 484, 13), // "toggle_header"
-QT_MOC_LITERAL(32, 498, 3), // "col"
-QT_MOC_LITERAL(33, 502, 21), // "contextmenu_requested"
-QT_MOC_LITERAL(34, 524, 16), // "contextmenu_open"
-QT_MOC_LITERAL(35, 541, 26), // "contextmenu_open_in_editor"
-QT_MOC_LITERAL(36, 568, 23), // "contextmenu_open_in_app"
-QT_MOC_LITERAL(37, 592, 26), // "contextmenu_copy_selection"
-QT_MOC_LITERAL(38, 619, 15), // "contextmenu_run"
-QT_MOC_LITERAL(39, 635, 16), // "contextmenu_load"
-QT_MOC_LITERAL(40, 652, 18), // "contextmenu_rename"
-QT_MOC_LITERAL(41, 671, 18), // "contextmenu_delete"
-QT_MOC_LITERAL(42, 690, 19), // "contextmenu_newfile"
-QT_MOC_LITERAL(43, 710, 18), // "contextmenu_newdir"
-QT_MOC_LITERAL(44, 729, 25), // "contextmenu_setcurrentdir"
-QT_MOC_LITERAL(45, 755, 21), // "contextmenu_findfiles"
-QT_MOC_LITERAL(46, 777, 19), // "popdownmenu_newfile"
-QT_MOC_LITERAL(47, 797, 18), // "popdownmenu_newdir"
-QT_MOC_LITERAL(48, 816, 22), // "popdownmenu_search_dir"
-QT_MOC_LITERAL(49, 839, 21), // "popdownmenu_findfiles"
-QT_MOC_LITERAL(50, 861, 16), // "popdownmenu_home"
-QT_MOC_LITERAL(51, 878, 13), // "copyClipboard"
-QT_MOC_LITERAL(52, 892, 14), // "pasteClipboard"
-QT_MOC_LITERAL(53, 907, 9) // "selectAll"
+QT_MOC_LITERAL(17, 226, 18), // "modify_path_signal"
+QT_MOC_LITERAL(18, 245, 8), // "dir_list"
+QT_MOC_LITERAL(19, 254, 2), // "rm"
+QT_MOC_LITERAL(20, 257, 7), // "subdirs"
+QT_MOC_LITERAL(21, 265, 19), // "item_double_clicked"
+QT_MOC_LITERAL(22, 285, 5), // "index"
+QT_MOC_LITERAL(23, 291, 19), // "change_directory_up"
+QT_MOC_LITERAL(24, 311, 24), // "do_sync_octave_directory"
+QT_MOC_LITERAL(25, 336, 25), // "do_sync_browser_directory"
+QT_MOC_LITERAL(26, 362, 21), // "set_current_directory"
+QT_MOC_LITERAL(27, 384, 26), // "accept_directory_line_edit"
+QT_MOC_LITERAL(28, 411, 23), // "update_octave_directory"
+QT_MOC_LITERAL(29, 435, 15), // "notice_settings"
+QT_MOC_LITERAL(30, 451, 19), // "const gui_settings*"
+QT_MOC_LITERAL(31, 471, 8), // "settings"
+QT_MOC_LITERAL(32, 480, 13), // "save_settings"
+QT_MOC_LITERAL(33, 494, 27), // "headercontextmenu_requested"
+QT_MOC_LITERAL(34, 522, 3), // "pos"
+QT_MOC_LITERAL(35, 526, 13), // "toggle_header"
+QT_MOC_LITERAL(36, 540, 3), // "col"
+QT_MOC_LITERAL(37, 544, 21), // "contextmenu_requested"
+QT_MOC_LITERAL(38, 566, 16), // "contextmenu_open"
+QT_MOC_LITERAL(39, 583, 26), // "contextmenu_open_in_editor"
+QT_MOC_LITERAL(40, 610, 23), // "contextmenu_open_in_app"
+QT_MOC_LITERAL(41, 634, 26), // "contextmenu_copy_selection"
+QT_MOC_LITERAL(42, 661, 15), // "contextmenu_run"
+QT_MOC_LITERAL(43, 677, 16), // "contextmenu_load"
+QT_MOC_LITERAL(44, 694, 18), // "contextmenu_rename"
+QT_MOC_LITERAL(45, 713, 18), // "contextmenu_delete"
+QT_MOC_LITERAL(46, 732, 19), // "contextmenu_newfile"
+QT_MOC_LITERAL(47, 752, 18), // "contextmenu_newdir"
+QT_MOC_LITERAL(48, 771, 25), // "contextmenu_setcurrentdir"
+QT_MOC_LITERAL(49, 797, 23), // "contextmenu_add_to_path"
+QT_MOC_LITERAL(50, 821, 31), // "contextmenu_add_to_path_subdirs"
+QT_MOC_LITERAL(51, 853, 24), // "contextmenu_rm_from_path"
+QT_MOC_LITERAL(52, 878, 32), // "contextmenu_rm_from_path_subdirs"
+QT_MOC_LITERAL(53, 911, 21), // "contextmenu_findfiles"
+QT_MOC_LITERAL(54, 933, 19), // "popdownmenu_newfile"
+QT_MOC_LITERAL(55, 953, 18), // "popdownmenu_newdir"
+QT_MOC_LITERAL(56, 972, 22), // "popdownmenu_search_dir"
+QT_MOC_LITERAL(57, 995, 21), // "popdownmenu_findfiles"
+QT_MOC_LITERAL(58, 1017, 16), // "popdownmenu_home"
+QT_MOC_LITERAL(59, 1034, 13), // "copyClipboard"
+QT_MOC_LITERAL(60, 1048, 14), // "pasteClipboard"
+QT_MOC_LITERAL(61, 1063, 9) // "selectAll"
 
     },
     "octave::files_dock_widget\0open_file\0"
@@ -96,13 +104,14 @@ QT_MOC_LITERAL(53, 907, 9) // "selectAll"
     "run_file_signal\0QFileInfo\0info\0"
     "find_files_signal\0startdir\0"
     "file_remove_signal\0old_name\0new_name\0"
-    "file_renamed_signal\0item_double_clicked\0"
+    "file_renamed_signal\0modify_path_signal\0"
+    "dir_list\0rm\0subdirs\0item_double_clicked\0"
     "index\0change_directory_up\0"
     "do_sync_octave_directory\0"
     "do_sync_browser_directory\0"
     "set_current_directory\0accept_directory_line_edit\0"
     "update_octave_directory\0notice_settings\0"
-    "const QSettings*\0settings\0save_settings\0"
+    "const gui_settings*\0settings\0save_settings\0"
     "headercontextmenu_requested\0pos\0"
     "toggle_header\0col\0contextmenu_requested\0"
     "contextmenu_open\0contextmenu_open_in_editor\0"
@@ -111,6 +120,10 @@ QT_MOC_LITERAL(53, 907, 9) // "selectAll"
     "contextmenu_load\0contextmenu_rename\0"
     "contextmenu_delete\0contextmenu_newfile\0"
     "contextmenu_newdir\0contextmenu_setcurrentdir\0"
+    "contextmenu_add_to_path\0"
+    "contextmenu_add_to_path_subdirs\0"
+    "contextmenu_rm_from_path\0"
+    "contextmenu_rm_from_path_subdirs\0"
     "contextmenu_findfiles\0popdownmenu_newfile\0"
     "popdownmenu_newdir\0popdownmenu_search_dir\0"
     "popdownmenu_findfiles\0popdownmenu_home\0"
@@ -124,56 +137,63 @@ static const uint qt_meta_data_octave__files_dock_widget[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-      40,   14, // methods
+      47,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
        0,       // flags
-       8,       // signalCount
+       9,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    1,  214,    2, 0x06 /* Public */,
-       4,    1,  217,    2, 0x06 /* Public */,
-       6,    1,  220,    2, 0x06 /* Public */,
-       7,    1,  223,    2, 0x06 /* Public */,
-       8,    1,  226,    2, 0x06 /* Public */,
-      11,    1,  229,    2, 0x06 /* Public */,
-      13,    2,  232,    2, 0x06 /* Public */,
-      16,    1,  237,    2, 0x06 /* Public */,
+       1,    1,  249,    2, 0x06 /* Public */,
+       4,    1,  252,    2, 0x06 /* Public */,
+       6,    1,  255,    2, 0x06 /* Public */,
+       7,    1,  258,    2, 0x06 /* Public */,
+       8,    1,  261,    2, 0x06 /* Public */,
+      11,    1,  264,    2, 0x06 /* Public */,
+      13,    2,  267,    2, 0x06 /* Public */,
+      16,    1,  272,    2, 0x06 /* Public */,
+      17,    3,  275,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-      17,    1,  240,    2, 0x0a /* Public */,
-      19,    0,  243,    2, 0x0a /* Public */,
-      20,    0,  244,    2, 0x0a /* Public */,
-      21,    0,  245,    2, 0x0a /* Public */,
-      22,    1,  246,    2, 0x0a /* Public */,
-      23,    0,  249,    2, 0x0a /* Public */,
-      24,    1,  250,    2, 0x0a /* Public */,
-      25,    1,  253,    2, 0x0a /* Public */,
-      28,    0,  256,    2, 0x0a /* Public */,
-      29,    1,  257,    2, 0x08 /* Private */,
-      31,    1,  260,    2, 0x08 /* Private */,
-      33,    1,  263,    2, 0x08 /* Private */,
-      34,    1,  266,    2, 0x08 /* Private */,
-      35,    1,  269,    2, 0x08 /* Private */,
-      36,    1,  272,    2, 0x08 /* Private */,
-      37,    1,  275,    2, 0x08 /* Private */,
-      38,    1,  278,    2, 0x08 /* Private */,
-      39,    1,  281,    2, 0x08 /* Private */,
-      40,    1,  284,    2, 0x08 /* Private */,
-      41,    1,  287,    2, 0x08 /* Private */,
-      42,    1,  290,    2, 0x08 /* Private */,
-      43,    1,  293,    2, 0x08 /* Private */,
-      44,    1,  296,    2, 0x08 /* Private */,
-      45,    1,  299,    2, 0x08 /* Private */,
-      46,    1,  302,    2, 0x08 /* Private */,
-      47,    1,  305,    2, 0x08 /* Private */,
-      48,    1,  308,    2, 0x08 /* Private */,
-      49,    1,  311,    2, 0x08 /* Private */,
-      50,    1,  314,    2, 0x08 /* Private */,
-      51,    0,  317,    2, 0x08 /* Private */,
-      52,    0,  318,    2, 0x08 /* Private */,
-      53,    0,  319,    2, 0x08 /* Private */,
+      21,    1,  282,    2, 0x0a /* Public */,
+      23,    0,  285,    2, 0x0a /* Public */,
+      24,    0,  286,    2, 0x0a /* Public */,
+      25,    0,  287,    2, 0x0a /* Public */,
+      26,    1,  288,    2, 0x0a /* Public */,
+      27,    0,  291,    2, 0x0a /* Public */,
+      28,    1,  292,    2, 0x0a /* Public */,
+      29,    1,  295,    2, 0x0a /* Public */,
+      32,    0,  298,    2, 0x0a /* Public */,
+      33,    1,  299,    2, 0x08 /* Private */,
+      35,    1,  302,    2, 0x08 /* Private */,
+      37,    1,  305,    2, 0x08 /* Private */,
+      38,    1,  308,    2, 0x08 /* Private */,
+      39,    1,  311,    2, 0x08 /* Private */,
+      40,    1,  314,    2, 0x08 /* Private */,
+      41,    1,  317,    2, 0x08 /* Private */,
+      42,    1,  320,    2, 0x08 /* Private */,
+      43,    1,  323,    2, 0x08 /* Private */,
+      44,    1,  326,    2, 0x08 /* Private */,
+      45,    1,  329,    2, 0x08 /* Private */,
+      46,    1,  332,    2, 0x08 /* Private */,
+      47,    1,  335,    2, 0x08 /* Private */,
+      48,    1,  338,    2, 0x08 /* Private */,
+      49,    3,  341,    2, 0x08 /* Private */,
+      49,    2,  348,    2, 0x28 /* Private | MethodCloned */,
+      49,    1,  353,    2, 0x28 /* Private | MethodCloned */,
+      50,    1,  356,    2, 0x08 /* Private */,
+      51,    1,  359,    2, 0x08 /* Private */,
+      52,    1,  362,    2, 0x08 /* Private */,
+      53,    1,  365,    2, 0x08 /* Private */,
+      54,    1,  368,    2, 0x08 /* Private */,
+      55,    1,  371,    2, 0x08 /* Private */,
+      56,    1,  374,    2, 0x08 /* Private */,
+      57,    1,  377,    2, 0x08 /* Private */,
+      58,    1,  380,    2, 0x08 /* Private */,
+      59,    0,  383,    2, 0x08 /* Private */,
+      60,    0,  384,    2, 0x08 /* Private */,
+      61,    0,  385,    2, 0x08 /* Private */,
 
  // signals: parameters
     QMetaType::Void, QMetaType::QString,    3,
@@ -184,20 +204,21 @@ static const uint qt_meta_data_octave__files_dock_widget[] = {
     QMetaType::Void, QMetaType::QString,   12,
     QMetaType::Void, QMetaType::QString, QMetaType::QString,   14,   15,
     QMetaType::Void, QMetaType::Bool,    2,
+    QMetaType::Void, QMetaType::QStringList, QMetaType::Bool, QMetaType::Bool,   18,   19,   20,
 
  // slots: parameters
-    QMetaType::Void, QMetaType::QModelIndex,   18,
+    QMetaType::Void, QMetaType::QModelIndex,   22,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void, QMetaType::QString,    5,
     QMetaType::Void,
     QMetaType::Void, QMetaType::QString,    5,
-    QMetaType::Void, 0x80000000 | 26,   27,
+    QMetaType::Void, 0x80000000 | 30,   31,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::QPoint,   30,
-    QMetaType::Void, QMetaType::Int,   32,
-    QMetaType::Void, QMetaType::QPoint,   30,
+    QMetaType::Void, QMetaType::QPoint,   34,
+    QMetaType::Void, QMetaType::Int,   36,
+    QMetaType::Void, QMetaType::QPoint,   34,
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
@@ -209,6 +230,12 @@ static const uint qt_meta_data_octave__files_dock_widget[] = {
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
+    QMetaType::Void, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool,    2,   19,   20,
+    QMetaType::Void, QMetaType::Bool, QMetaType::Bool,    2,   19,
+    QMetaType::Void, QMetaType::Bool,    2,
+    QMetaType::Void, QMetaType::Bool,    2,
+    QMetaType::Void, QMetaType::Bool,    2,
+    QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
@@ -236,38 +263,45 @@ void octave::files_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Cal
         case 5: _t->find_files_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
         case 6: _t->file_remove_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
         case 7: _t->file_renamed_signal((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 8: _t->item_double_clicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
-        case 9: _t->change_directory_up(); break;
-        case 10: _t->do_sync_octave_directory(); break;
-        case 11: _t->do_sync_browser_directory(); break;
-        case 12: _t->set_current_directory((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 13: _t->accept_directory_line_edit(); break;
-        case 14: _t->update_octave_directory((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 15: _t->notice_settings((*reinterpret_cast< const QSettings*(*)>(_a[1]))); break;
-        case 16: _t->save_settings(); break;
-        case 17: _t->headercontextmenu_requested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
-        case 18: _t->toggle_header((*reinterpret_cast< int(*)>(_a[1]))); break;
-        case 19: _t->contextmenu_requested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
-        case 20: _t->contextmenu_open((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 21: _t->contextmenu_open_in_editor((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 22: _t->contextmenu_open_in_app((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 23: _t->contextmenu_copy_selection((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 24: _t->contextmenu_run((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 25: _t->contextmenu_load((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 26: _t->contextmenu_rename((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 27: _t->contextmenu_delete((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 28: _t->contextmenu_newfile((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 29: _t->contextmenu_newdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 30: _t->contextmenu_setcurrentdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 31: _t->contextmenu_findfiles((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 32: _t->popdownmenu_newfile((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 33: _t->popdownmenu_newdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 34: _t->popdownmenu_search_dir((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 35: _t->popdownmenu_findfiles((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 36: _t->popdownmenu_home((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 37: _t->copyClipboard(); break;
-        case 38: _t->pasteClipboard(); break;
-        case 39: _t->selectAll(); break;
+        case 8: _t->modify_path_signal((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
+        case 9: _t->item_double_clicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
+        case 10: _t->change_directory_up(); break;
+        case 11: _t->do_sync_octave_directory(); break;
+        case 12: _t->do_sync_browser_directory(); break;
+        case 13: _t->set_current_directory((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 14: _t->accept_directory_line_edit(); break;
+        case 15: _t->update_octave_directory((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 16: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
+        case 17: _t->save_settings(); break;
+        case 18: _t->headercontextmenu_requested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
+        case 19: _t->toggle_header((*reinterpret_cast< int(*)>(_a[1]))); break;
+        case 20: _t->contextmenu_requested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
+        case 21: _t->contextmenu_open((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 22: _t->contextmenu_open_in_editor((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 23: _t->contextmenu_open_in_app((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 24: _t->contextmenu_copy_selection((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 25: _t->contextmenu_run((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 26: _t->contextmenu_load((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 27: _t->contextmenu_rename((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 28: _t->contextmenu_delete((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 29: _t->contextmenu_newfile((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 30: _t->contextmenu_newdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 31: _t->contextmenu_setcurrentdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 32: _t->contextmenu_add_to_path((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
+        case 33: _t->contextmenu_add_to_path((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
+        case 34: _t->contextmenu_add_to_path((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 35: _t->contextmenu_add_to_path_subdirs((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 36: _t->contextmenu_rm_from_path((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 37: _t->contextmenu_rm_from_path_subdirs((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 38: _t->contextmenu_findfiles((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 39: _t->popdownmenu_newfile((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 40: _t->popdownmenu_newdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 41: _t->popdownmenu_search_dir((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 42: _t->popdownmenu_findfiles((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 43: _t->popdownmenu_home((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 44: _t->copyClipboard(); break;
+        case 45: _t->pasteClipboard(); break;
+        case 46: _t->selectAll(); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -328,6 +362,13 @@ void octave::files_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Cal
                 return;
             }
         }
+        {
+            typedef void (files_dock_widget::*_t)(const QStringList & , bool , bool );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&files_dock_widget::modify_path_signal)) {
+                *result = 8;
+                return;
+            }
+        }
     }
 }
 
@@ -356,13 +397,13 @@ int octave::files_dock_widget::qt_metacall(QMetaObject::Call _c, int _id, void *
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 40)
+        if (_id < 47)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 40;
+        _id -= 47;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 40)
+        if (_id < 47)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 40;
+        _id -= 47;
     }
     return _id;
 }
@@ -422,5 +463,12 @@ void octave::files_dock_widget::file_renamed_signal(bool _t1)
     void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
     QMetaObject::activate(this, &staticMetaObject, 7, _a);
 }
+
+// SIGNAL 8
+void octave::files_dock_widget::modify_path_signal(const QStringList & _t1, bool _t2, bool _t3)
+{
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
+    QMetaObject::activate(this, &staticMetaObject, 8, _a);
+}
 QT_WARNING_POP
 QT_END_MOC_NAMESPACE
