@@ -2,18 +2,18 @@
 #  include "config.h"
 #endif
 /****************************************************************************
-** Meta object code from reading C++ file 'shortcut-manager.h'
+** Meta object code from reading C++ file 'moc-shortcut-manager.h'
 **
 ** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/src/shortcut-manager.h"
+#include "libgui/src/moc-shortcut-manager.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
-#error "The header file 'shortcut-manager.h' doesn't include <QObject>."
+#error "The header file 'moc-shortcut-manager.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 67
 #error "This file was generated using the moc from 5.9.4. It"
 #error "cannot be used with the include files from this version of Qt."
@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_octave__enter_shortcut_t {
-    QByteArrayData data[3];
-    char stringdata0[47];
+    QByteArrayData data[4];
+    char stringdata0[69];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -36,11 +36,12 @@ static const qt_meta_stringdata_octave__enter_shortcut_t qt_meta_stringdata_octa
     {
 QT_MOC_LITERAL(0, 0, 22), // "octave::enter_shortcut"
 QT_MOC_LITERAL(1, 23, 22), // "handle_direct_shortcut"
-QT_MOC_LITERAL(2, 46, 0) // ""
+QT_MOC_LITERAL(2, 46, 0), // ""
+QT_MOC_LITERAL(3, 47, 21) // "handle_shift_modifier"
 
     },
     "octave::enter_shortcut\0handle_direct_shortcut\0"
-    ""
+    "\0handle_shift_modifier"
 };
 #undef QT_MOC_LITERAL
 
@@ -50,7 +51,7 @@ static const uint qt_meta_data_octave__enter_shortcut[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-       1,   14, // methods
+       2,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
@@ -58,9 +59,11 @@ static const uint qt_meta_data_octave__enter_shortcut[] = {
        0,       // signalCount
 
  // slots: name, argc, parameters, tag, flags
-       1,    1,   19,    2, 0x0a /* Public */,
+       1,    1,   24,    2, 0x0a /* Public */,
+       3,    1,   27,    2, 0x0a /* Public */,
 
  // slots: parameters
+    QMetaType::Void, QMetaType::Int,    2,
     QMetaType::Void, QMetaType::Int,    2,
 
        0        // eod
@@ -73,6 +76,7 @@ void octave::enter_shortcut::qt_static_metacall(QObject *_o, QMetaObject::Call _
         Q_UNUSED(_t)
         switch (_id) {
         case 0: _t->handle_direct_shortcut((*reinterpret_cast< int(*)>(_a[1]))); break;
+        case 1: _t->handle_shift_modifier((*reinterpret_cast< int(*)>(_a[1]))); break;
         default: ;
         }
     }
@@ -103,19 +107,19 @@ int octave::enter_shortcut::qt_metacall(QMetaObject::Call _c, int _id, void **_a
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 1)
+        if (_id < 2)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 1;
+        _id -= 2;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 1)
+        if (_id < 2)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 1;
+        _id -= 2;
     }
     return _id;
 }
 struct qt_meta_stringdata_octave__shortcut_manager_t {
-    QByteArrayData data[7];
-    char stringdata0[135];
+    QByteArrayData data[6];
+    char stringdata0[118];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -125,17 +129,15 @@ struct qt_meta_stringdata_octave__shortcut_manager_t {
 static const qt_meta_stringdata_octave__shortcut_manager_t qt_meta_stringdata_octave__shortcut_manager = {
     {
 QT_MOC_LITERAL(0, 0, 24), // "octave::shortcut_manager"
-QT_MOC_LITERAL(1, 25, 16), // "cleanup_instance"
-QT_MOC_LITERAL(2, 42, 0), // ""
-QT_MOC_LITERAL(3, 43, 21), // "handle_double_clicked"
-QT_MOC_LITERAL(4, 65, 16), // "QTreeWidgetItem*"
-QT_MOC_LITERAL(5, 82, 24), // "shortcut_dialog_finished"
-QT_MOC_LITERAL(6, 107, 27) // "shortcut_dialog_set_default"
+QT_MOC_LITERAL(1, 25, 21), // "handle_double_clicked"
+QT_MOC_LITERAL(2, 47, 0), // ""
+QT_MOC_LITERAL(3, 48, 16), // "QTreeWidgetItem*"
+QT_MOC_LITERAL(4, 65, 24), // "shortcut_dialog_finished"
+QT_MOC_LITERAL(5, 90, 27) // "shortcut_dialog_set_default"
 
     },
-    "octave::shortcut_manager\0cleanup_instance\0"
-    "\0handle_double_clicked\0QTreeWidgetItem*\0"
-    "shortcut_dialog_finished\0"
+    "octave::shortcut_manager\0handle_double_clicked\0"
+    "\0QTreeWidgetItem*\0shortcut_dialog_finished\0"
     "shortcut_dialog_set_default"
 };
 #undef QT_MOC_LITERAL
@@ -146,7 +148,7 @@ static const uint qt_meta_data_octave__shortcut_manager[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-       4,   14, // methods
+       3,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
@@ -154,14 +156,12 @@ static const uint qt_meta_data_octave__shortcut_manager[] = {
        0,       // signalCount
 
  // slots: name, argc, parameters, tag, flags
-       1,    0,   34,    2, 0x0a /* Public */,
-       3,    2,   35,    2, 0x09 /* Protected */,
-       5,    1,   40,    2, 0x09 /* Protected */,
-       6,    0,   43,    2, 0x09 /* Protected */,
+       1,    2,   29,    2, 0x09 /* Protected */,
+       4,    1,   34,    2, 0x09 /* Protected */,
+       5,    0,   37,    2, 0x09 /* Protected */,
 
  // slots: parameters
-    QMetaType::Void,
-    QMetaType::Void, 0x80000000 | 4, QMetaType::Int,    2,    2,
+    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    2,    2,
     QMetaType::Void, QMetaType::Int,    2,
     QMetaType::Void,
 
@@ -174,10 +174,9 @@ void octave::shortcut_manager::qt_static_metacall(QObject *_o, QMetaObject::Call
         shortcut_manager *_t = static_cast<shortcut_manager *>(_o);
         Q_UNUSED(_t)
         switch (_id) {
-        case 0: _t->cleanup_instance(); break;
-        case 1: _t->handle_double_clicked((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
-        case 2: _t->shortcut_dialog_finished((*reinterpret_cast< int(*)>(_a[1]))); break;
-        case 3: _t->shortcut_dialog_set_default(); break;
+        case 0: _t->handle_double_clicked((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
+        case 1: _t->shortcut_dialog_finished((*reinterpret_cast< int(*)>(_a[1]))); break;
+        case 2: _t->shortcut_dialog_set_default(); break;
         default: ;
         }
     }
@@ -208,13 +207,13 @@ int octave::shortcut_manager::qt_metacall(QMetaObject::Call _c, int _id, void **
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 4)
+        if (_id < 3)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 4;
+        _id -= 3;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 4)
+        if (_id < 3)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 4;
+        _id -= 3;
     }
     return _id;
 }
