@@ -2,18 +2,18 @@
 #  include "config.h"
 #endif
 /****************************************************************************
-** Meta object code from reading C++ file 'variable-editor.h'
+** Meta object code from reading C++ file 'moc-variable-editor.h'
 **
 ** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.i686/src/octave-5.1.0/libgui/src/variable-editor.h"
+#include "libgui/src/moc-variable-editor.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
-#error "The header file 'variable-editor.h' doesn't include <QObject>."
+#error "The header file 'moc-variable-editor.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 67
 #error "This file was generated using the moc from 5.9.4. It"
 #error "cannot be used with the include files from this version of Qt."
@@ -205,8 +205,8 @@ void octave::variable_dock_widget::queue_float()
     QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
 }
 struct qt_meta_stringdata_octave__variable_editor_stack_t {
-    QByteArrayData data[12];
-    char stringdata0[128];
+    QByteArrayData data[19];
+    char stringdata0[203];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -216,23 +216,32 @@ struct qt_meta_stringdata_octave__variable_editor_stack_t {
 static const qt_meta_stringdata_octave__variable_editor_stack_t qt_meta_stringdata_octave__variable_editor_stack = {
     {
 QT_MOC_LITERAL(0, 0, 29), // "octave::variable_editor_stack"
-QT_MOC_LITERAL(1, 30, 14), // "command_signal"
-QT_MOC_LITERAL(2, 45, 0), // ""
-QT_MOC_LITERAL(3, 46, 3), // "cmd"
-QT_MOC_LITERAL(4, 50, 20), // "edit_variable_signal"
-QT_MOC_LITERAL(5, 71, 4), // "name"
-QT_MOC_LITERAL(6, 76, 12), // "octave_value"
-QT_MOC_LITERAL(7, 89, 3), // "val"
-QT_MOC_LITERAL(8, 93, 12), // "set_editable"
-QT_MOC_LITERAL(9, 106, 8), // "editable"
-QT_MOC_LITERAL(10, 115, 7), // "levelUp"
-QT_MOC_LITERAL(11, 123, 4) // "save"
+QT_MOC_LITERAL(1, 30, 20), // "edit_variable_signal"
+QT_MOC_LITERAL(2, 51, 0), // ""
+QT_MOC_LITERAL(3, 52, 4), // "name"
+QT_MOC_LITERAL(4, 57, 12), // "octave_value"
+QT_MOC_LITERAL(5, 70, 3), // "val"
+QT_MOC_LITERAL(6, 74, 14), // "do_save_signal"
+QT_MOC_LITERAL(7, 89, 6), // "format"
+QT_MOC_LITERAL(8, 96, 9), // "save_opts"
+QT_MOC_LITERAL(9, 106, 17), // "interpreter_event"
+QT_MOC_LITERAL(10, 124, 12), // "fcn_callback"
+QT_MOC_LITERAL(11, 137, 3), // "fcn"
+QT_MOC_LITERAL(12, 141, 13), // "meth_callback"
+QT_MOC_LITERAL(13, 155, 4), // "meth"
+QT_MOC_LITERAL(14, 160, 12), // "set_editable"
+QT_MOC_LITERAL(15, 173, 8), // "editable"
+QT_MOC_LITERAL(16, 182, 7), // "levelUp"
+QT_MOC_LITERAL(17, 190, 4), // "save"
+QT_MOC_LITERAL(18, 195, 7) // "do_save"
 
     },
     "octave::variable_editor_stack\0"
-    "command_signal\0\0cmd\0edit_variable_signal\0"
-    "name\0octave_value\0val\0set_editable\0"
-    "editable\0levelUp\0save"
+    "edit_variable_signal\0\0name\0octave_value\0"
+    "val\0do_save_signal\0format\0save_opts\0"
+    "interpreter_event\0fcn_callback\0fcn\0"
+    "meth_callback\0meth\0set_editable\0"
+    "editable\0levelUp\0save\0do_save"
 };
 #undef QT_MOC_LITERAL
 
@@ -242,30 +251,38 @@ static const uint qt_meta_data_octave__variable_editor_stack[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-       5,   14, // methods
+       9,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
        0,       // flags
-       2,       // signalCount
+       4,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    1,   39,    2, 0x06 /* Public */,
-       4,    2,   42,    2, 0x06 /* Public */,
+       1,    2,   59,    2, 0x06 /* Public */,
+       6,    2,   64,    2, 0x06 /* Public */,
+       9,    1,   69,    2, 0x06 /* Public */,
+       9,    1,   72,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-       8,    1,   47,    2, 0x0a /* Public */,
-      10,    0,   50,    2, 0x0a /* Public */,
-      11,    0,   51,    2, 0x0a /* Public */,
+      14,    1,   75,    2, 0x0a /* Public */,
+      16,    0,   78,    2, 0x0a /* Public */,
+      17,    1,   79,    2, 0x0a /* Public */,
+      17,    0,   82,    2, 0x2a /* Public | MethodCloned */,
+      18,    2,   83,    2, 0x0a /* Public */,
 
  // signals: parameters
-    QMetaType::Void, QMetaType::QString,    3,
-    QMetaType::Void, QMetaType::QString, 0x80000000 | 6,    5,    7,
+    QMetaType::Void, QMetaType::QString, 0x80000000 | 4,    3,    5,
+    QMetaType::Void, QMetaType::QString, QMetaType::QString,    7,    8,
+    QMetaType::Void, 0x80000000 | 10,   11,
+    QMetaType::Void, 0x80000000 | 12,   13,
 
  // slots: parameters
-    QMetaType::Void, QMetaType::Bool,    9,
+    QMetaType::Void, QMetaType::Bool,   15,
     QMetaType::Void,
+    QMetaType::Void, QMetaType::QString,    7,
     QMetaType::Void,
+    QMetaType::Void, QMetaType::QString, QMetaType::QString,    7,    8,
 
        0        // eod
 };
@@ -276,29 +293,47 @@ void octave::variable_editor_stack::qt_static_metacall(QObject *_o, QMetaObject:
         variable_editor_stack *_t = static_cast<variable_editor_stack *>(_o);
         Q_UNUSED(_t)
         switch (_id) {
-        case 0: _t->command_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 1: _t->edit_variable_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const octave_value(*)>(_a[2]))); break;
-        case 2: _t->set_editable((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 3: _t->levelUp(); break;
-        case 4: _t->save(); break;
+        case 0: _t->edit_variable_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const octave_value(*)>(_a[2]))); break;
+        case 1: _t->do_save_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
+        case 2: _t->interpreter_event((*reinterpret_cast< const fcn_callback(*)>(_a[1]))); break;
+        case 3: _t->interpreter_event((*reinterpret_cast< const meth_callback(*)>(_a[1]))); break;
+        case 4: _t->set_editable((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 5: _t->levelUp(); break;
+        case 6: _t->save((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 7: _t->save(); break;
+        case 8: _t->do_save((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
         int *result = reinterpret_cast<int *>(_a[0]);
         {
-            typedef void (variable_editor_stack::*_t)(const QString & );
-            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor_stack::command_signal)) {
+            typedef void (variable_editor_stack::*_t)(const QString & , const octave_value & );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor_stack::edit_variable_signal)) {
                 *result = 0;
                 return;
             }
         }
         {
-            typedef void (variable_editor_stack::*_t)(const QString & , const octave_value & );
-            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor_stack::edit_variable_signal)) {
+            typedef void (variable_editor_stack::*_t)(const QString & , const QString & );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor_stack::do_save_signal)) {
                 *result = 1;
                 return;
             }
         }
+        {
+            typedef void (variable_editor_stack::*_t)(const fcn_callback & );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor_stack::interpreter_event)) {
+                *result = 2;
+                return;
+            }
+        }
+        {
+            typedef void (variable_editor_stack::*_t)(const meth_callback & );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor_stack::interpreter_event)) {
+                *result = 3;
+                return;
+            }
+        }
     }
 }
 
@@ -327,33 +362,47 @@ int octave::variable_editor_stack::qt_metacall(QMetaObject::Call _c, int _id, vo
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 5)
+        if (_id < 9)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 5;
+        _id -= 9;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 5)
+        if (_id < 9)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 5;
+        _id -= 9;
     }
     return _id;
 }
 
 // SIGNAL 0
-void octave::variable_editor_stack::command_signal(const QString & _t1)
+void octave::variable_editor_stack::edit_variable_signal(const QString & _t1, const octave_value & _t2)
 {
-    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
     QMetaObject::activate(this, &staticMetaObject, 0, _a);
 }
 
 // SIGNAL 1
-void octave::variable_editor_stack::edit_variable_signal(const QString & _t1, const octave_value & _t2)
+void octave::variable_editor_stack::do_save_signal(const QString & _t1, const QString & _t2)
 {
     void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
     QMetaObject::activate(this, &staticMetaObject, 1, _a);
 }
+
+// SIGNAL 2
+void octave::variable_editor_stack::interpreter_event(const fcn_callback & _t1)
+{
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
+    QMetaObject::activate(this, &staticMetaObject, 2, _a);
+}
+
+// SIGNAL 3
+void octave::variable_editor_stack::interpreter_event(const meth_callback & _t1)
+{
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
+    QMetaObject::activate(this, &staticMetaObject, 3, _a);
+}
 struct qt_meta_stringdata_octave__variable_editor_view_t {
-    QByteArrayData data[26];
-    char stringdata0[398];
+    QByteArrayData data[25];
+    char stringdata0[379];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -386,8 +435,7 @@ QT_MOC_LITERAL(20, 300, 17), // "createContextMenu"
 QT_MOC_LITERAL(21, 318, 2), // "pt"
 QT_MOC_LITERAL(22, 321, 16), // "createColumnMenu"
 QT_MOC_LITERAL(23, 338, 13), // "createRowMenu"
-QT_MOC_LITERAL(24, 352, 18), // "selected_to_octave"
-QT_MOC_LITERAL(25, 371, 26) // "selected_command_requested"
+QT_MOC_LITERAL(24, 352, 26) // "selected_command_requested"
 
     },
     "octave::variable_editor_view\0"
@@ -399,8 +447,7 @@ QT_MOC_LITERAL(25, 371, 26) // "selected_command_requested"
     "pasteClipboard\0handle_horizontal_scroll_action\0"
     "action\0handle_vertical_scroll_action\0"
     "createContextMenu\0pt\0createColumnMenu\0"
-    "createRowMenu\0selected_to_octave\0"
-    "selected_command_requested"
+    "createRowMenu\0selected_command_requested"
 };
 #undef QT_MOC_LITERAL
 
@@ -410,7 +457,7 @@ static const uint qt_meta_data_octave__variable_editor_view[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-      17,   14, // methods
+      16,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
@@ -418,25 +465,24 @@ static const uint qt_meta_data_octave__variable_editor_view[] = {
        2,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    1,   99,    2, 0x06 /* Public */,
-       4,    2,  102,    2, 0x06 /* Public */,
+       1,    1,   94,    2, 0x06 /* Public */,
+       4,    2,   97,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-       8,    0,  107,    2, 0x0a /* Public */,
-       9,    0,  108,    2, 0x0a /* Public */,
-      10,    0,  109,    2, 0x0a /* Public */,
-      12,    0,  110,    2, 0x0a /* Public */,
-      13,    0,  111,    2, 0x0a /* Public */,
-      14,    0,  112,    2, 0x0a /* Public */,
-      15,    0,  113,    2, 0x0a /* Public */,
-      16,    0,  114,    2, 0x0a /* Public */,
-      17,    1,  115,    2, 0x0a /* Public */,
-      19,    1,  118,    2, 0x0a /* Public */,
-      20,    1,  121,    2, 0x0a /* Public */,
-      22,    1,  124,    2, 0x0a /* Public */,
-      23,    1,  127,    2, 0x0a /* Public */,
-      24,    0,  130,    2, 0x0a /* Public */,
-      25,    1,  131,    2, 0x0a /* Public */,
+       8,    0,  102,    2, 0x0a /* Public */,
+       9,    0,  103,    2, 0x0a /* Public */,
+      10,    0,  104,    2, 0x0a /* Public */,
+      12,    0,  105,    2, 0x0a /* Public */,
+      13,    0,  106,    2, 0x0a /* Public */,
+      14,    0,  107,    2, 0x0a /* Public */,
+      15,    0,  108,    2, 0x0a /* Public */,
+      16,    0,  109,    2, 0x0a /* Public */,
+      17,    1,  110,    2, 0x0a /* Public */,
+      19,    1,  113,    2, 0x0a /* Public */,
+      20,    1,  116,    2, 0x0a /* Public */,
+      22,    1,  119,    2, 0x0a /* Public */,
+      23,    1,  122,    2, 0x0a /* Public */,
+      24,    1,  125,    2, 0x0a /* Public */,
 
  // signals: parameters
     QMetaType::Void, QMetaType::QString,    3,
@@ -456,7 +502,6 @@ static const uint qt_meta_data_octave__variable_editor_view[] = {
     QMetaType::Void, QMetaType::QPoint,   21,
     QMetaType::Void, QMetaType::QPoint,   21,
     QMetaType::Void, QMetaType::QPoint,   21,
-    QMetaType::QString,
     QMetaType::Void, QMetaType::QString,    3,
 
        0        // eod
@@ -484,9 +529,7 @@ void octave::variable_editor_view::qt_static_metacall(QObject *_o, QMetaObject::
         case 12: _t->createContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
         case 13: _t->createColumnMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
         case 14: _t->createRowMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
-        case 15: { QString _r = _t->selected_to_octave();
-            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
-        case 16: _t->selected_command_requested((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 15: _t->selected_command_requested((*reinterpret_cast< const QString(*)>(_a[1]))); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -533,13 +576,13 @@ int octave::variable_editor_view::qt_metacall(QMetaObject::Call _c, int _id, voi
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 17)
+        if (_id < 16)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 17;
+        _id -= 16;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 17)
+        if (_id < 16)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 17;
+        _id -= 16;
     }
     return _id;
 }
@@ -893,8 +936,8 @@ void octave::ReturnFocusMenu::about_to_activate()
     QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
 }
 struct qt_meta_stringdata_octave__variable_editor_t {
-    QByteArrayData data[34];
-    char stringdata0[500];
+    QByteArrayData data[37];
+    char stringdata0[510];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -916,27 +959,30 @@ QT_MOC_LITERAL(9, 119, 22), // "paste_clipboard_signal"
 QT_MOC_LITERAL(10, 142, 15), // "level_up_signal"
 QT_MOC_LITERAL(11, 158, 11), // "save_signal"
 QT_MOC_LITERAL(12, 170, 22), // "delete_selected_signal"
-QT_MOC_LITERAL(13, 193, 23), // "selected_command_signal"
-QT_MOC_LITERAL(14, 217, 10), // "callUpdate"
-QT_MOC_LITERAL(15, 228, 15), // "notice_settings"
-QT_MOC_LITERAL(16, 244, 16), // "const QSettings*"
-QT_MOC_LITERAL(17, 261, 13), // "edit_variable"
-QT_MOC_LITERAL(18, 275, 4), // "name"
-QT_MOC_LITERAL(19, 280, 12), // "octave_value"
-QT_MOC_LITERAL(20, 293, 3), // "val"
-QT_MOC_LITERAL(21, 297, 18), // "variable_destroyed"
-QT_MOC_LITERAL(22, 316, 3), // "obj"
-QT_MOC_LITERAL(23, 320, 16), // "variable_focused"
-QT_MOC_LITERAL(24, 337, 29), // "record_hovered_focus_variable"
-QT_MOC_LITERAL(25, 367, 30), // "restore_hovered_focus_variable"
-QT_MOC_LITERAL(26, 398, 10), // "closeEvent"
-QT_MOC_LITERAL(27, 409, 12), // "QCloseEvent*"
-QT_MOC_LITERAL(28, 422, 4), // "save"
-QT_MOC_LITERAL(29, 427, 12), // "cutClipboard"
-QT_MOC_LITERAL(30, 440, 13), // "copyClipboard"
-QT_MOC_LITERAL(31, 454, 14), // "pasteClipboard"
-QT_MOC_LITERAL(32, 469, 7), // "levelUp"
-QT_MOC_LITERAL(33, 477, 22) // "relay_selected_command"
+QT_MOC_LITERAL(13, 193, 17), // "interpreter_event"
+QT_MOC_LITERAL(14, 211, 12), // "fcn_callback"
+QT_MOC_LITERAL(15, 224, 3), // "fcn"
+QT_MOC_LITERAL(16, 228, 13), // "meth_callback"
+QT_MOC_LITERAL(17, 242, 4), // "meth"
+QT_MOC_LITERAL(18, 247, 10), // "callUpdate"
+QT_MOC_LITERAL(19, 258, 15), // "notice_settings"
+QT_MOC_LITERAL(20, 274, 19), // "const gui_settings*"
+QT_MOC_LITERAL(21, 294, 13), // "edit_variable"
+QT_MOC_LITERAL(22, 308, 4), // "name"
+QT_MOC_LITERAL(23, 313, 12), // "octave_value"
+QT_MOC_LITERAL(24, 326, 3), // "val"
+QT_MOC_LITERAL(25, 330, 18), // "variable_destroyed"
+QT_MOC_LITERAL(26, 349, 3), // "obj"
+QT_MOC_LITERAL(27, 353, 16), // "variable_focused"
+QT_MOC_LITERAL(28, 370, 29), // "record_hovered_focus_variable"
+QT_MOC_LITERAL(29, 400, 30), // "restore_hovered_focus_variable"
+QT_MOC_LITERAL(30, 431, 10), // "closeEvent"
+QT_MOC_LITERAL(31, 442, 12), // "QCloseEvent*"
+QT_MOC_LITERAL(32, 455, 4), // "save"
+QT_MOC_LITERAL(33, 460, 12), // "cutClipboard"
+QT_MOC_LITERAL(34, 473, 13), // "copyClipboard"
+QT_MOC_LITERAL(35, 487, 14), // "pasteClipboard"
+QT_MOC_LITERAL(36, 502, 7) // "levelUp"
 
     },
     "octave::variable_editor\0updated\0\0"
@@ -944,15 +990,15 @@ QT_MOC_LITERAL(33, 477, 22) // "relay_selected_command"
     "clear_content_signal\0copy_clipboard_signal\0"
     "paste_clipboard_signal\0level_up_signal\0"
     "save_signal\0delete_selected_signal\0"
-    "selected_command_signal\0callUpdate\0"
-    "notice_settings\0const QSettings*\0"
+    "interpreter_event\0fcn_callback\0fcn\0"
+    "meth_callback\0meth\0callUpdate\0"
+    "notice_settings\0const gui_settings*\0"
     "edit_variable\0name\0octave_value\0val\0"
     "variable_destroyed\0obj\0variable_focused\0"
     "record_hovered_focus_variable\0"
     "restore_hovered_focus_variable\0"
     "closeEvent\0QCloseEvent*\0save\0cutClipboard\0"
-    "copyClipboard\0pasteClipboard\0levelUp\0"
-    "relay_selected_command"
+    "copyClipboard\0pasteClipboard\0levelUp"
 };
 #undef QT_MOC_LITERAL
 
@@ -967,7 +1013,7 @@ static const uint qt_meta_data_octave__variable_editor[] = {
        0,    0, // enums/sets
        0,    0, // constructors
        0,       // flags
-      11,       // signalCount
+      12,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
        1,    0,  139,    2, 0x06 /* Public */,
@@ -981,22 +1027,22 @@ static const uint qt_meta_data_octave__variable_editor[] = {
       11,    0,  149,    2, 0x06 /* Public */,
       12,    0,  150,    2, 0x06 /* Public */,
       13,    1,  151,    2, 0x06 /* Public */,
+      13,    1,  154,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-      14,    2,  154,    2, 0x0a /* Public */,
-      15,    1,  159,    2, 0x0a /* Public */,
-      17,    2,  162,    2, 0x0a /* Public */,
-      21,    1,  167,    2, 0x0a /* Public */,
-      23,    1,  170,    2, 0x0a /* Public */,
-      24,    0,  173,    2, 0x0a /* Public */,
-      25,    0,  174,    2, 0x0a /* Public */,
-      26,    1,  175,    2, 0x09 /* Protected */,
-      28,    0,  178,    2, 0x09 /* Protected */,
-      29,    0,  179,    2, 0x09 /* Protected */,
-      30,    0,  180,    2, 0x09 /* Protected */,
-      31,    0,  181,    2, 0x09 /* Protected */,
-      32,    0,  182,    2, 0x09 /* Protected */,
-      33,    1,  183,    2, 0x09 /* Protected */,
+      18,    2,  157,    2, 0x0a /* Public */,
+      19,    1,  162,    2, 0x0a /* Public */,
+      21,    2,  165,    2, 0x0a /* Public */,
+      25,    1,  170,    2, 0x0a /* Public */,
+      27,    1,  173,    2, 0x0a /* Public */,
+      28,    0,  176,    2, 0x0a /* Public */,
+      29,    0,  177,    2, 0x0a /* Public */,
+      30,    1,  178,    2, 0x09 /* Protected */,
+      32,    0,  181,    2, 0x09 /* Protected */,
+      33,    0,  182,    2, 0x09 /* Protected */,
+      34,    0,  183,    2, 0x09 /* Protected */,
+      35,    0,  184,    2, 0x09 /* Protected */,
+      36,    0,  185,    2, 0x09 /* Protected */,
 
  // signals: parameters
     QMetaType::Void,
@@ -1009,23 +1055,23 @@ static const uint qt_meta_data_octave__variable_editor[] = {
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::QString,    5,
+    QMetaType::Void, 0x80000000 | 14,   15,
+    QMetaType::Void, 0x80000000 | 16,   17,
 
  // slots: parameters
     QMetaType::Void, QMetaType::QModelIndex, QMetaType::QModelIndex,    2,    2,
-    QMetaType::Void, 0x80000000 | 16,    2,
-    QMetaType::Void, QMetaType::QString, 0x80000000 | 19,   18,   20,
-    QMetaType::Void, QMetaType::QObjectStar,   22,
-    QMetaType::Void, QMetaType::QString,   18,
+    QMetaType::Void, 0x80000000 | 20,    2,
+    QMetaType::Void, QMetaType::QString, 0x80000000 | 23,   22,   24,
+    QMetaType::Void, QMetaType::QObjectStar,   26,
+    QMetaType::Void, QMetaType::QString,   22,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, 0x80000000 | 27,    2,
+    QMetaType::Void, 0x80000000 | 31,    2,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::QString,    5,
 
        0        // eod
 };
@@ -1046,21 +1092,21 @@ void octave::variable_editor::qt_static_metacall(QObject *_o, QMetaObject::Call
         case 7: _t->level_up_signal(); break;
         case 8: _t->save_signal(); break;
         case 9: _t->delete_selected_signal(); break;
-        case 10: _t->selected_command_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 11: _t->callUpdate((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
-        case 12: _t->notice_settings((*reinterpret_cast< const QSettings*(*)>(_a[1]))); break;
-        case 13: _t->edit_variable((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const octave_value(*)>(_a[2]))); break;
-        case 14: _t->variable_destroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
-        case 15: _t->variable_focused((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 16: _t->record_hovered_focus_variable(); break;
-        case 17: _t->restore_hovered_focus_variable(); break;
-        case 18: _t->closeEvent((*reinterpret_cast< QCloseEvent*(*)>(_a[1]))); break;
-        case 19: _t->save(); break;
-        case 20: _t->cutClipboard(); break;
-        case 21: _t->copyClipboard(); break;
-        case 22: _t->pasteClipboard(); break;
-        case 23: _t->levelUp(); break;
-        case 24: _t->relay_selected_command((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 10: _t->interpreter_event((*reinterpret_cast< const fcn_callback(*)>(_a[1]))); break;
+        case 11: _t->interpreter_event((*reinterpret_cast< const meth_callback(*)>(_a[1]))); break;
+        case 12: _t->callUpdate((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
+        case 13: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
+        case 14: _t->edit_variable((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const octave_value(*)>(_a[2]))); break;
+        case 15: _t->variable_destroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
+        case 16: _t->variable_focused((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 17: _t->record_hovered_focus_variable(); break;
+        case 18: _t->restore_hovered_focus_variable(); break;
+        case 19: _t->closeEvent((*reinterpret_cast< QCloseEvent*(*)>(_a[1]))); break;
+        case 20: _t->save(); break;
+        case 21: _t->cutClipboard(); break;
+        case 22: _t->copyClipboard(); break;
+        case 23: _t->pasteClipboard(); break;
+        case 24: _t->levelUp(); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -1136,12 +1182,19 @@ void octave::variable_editor::qt_static_metacall(QObject *_o, QMetaObject::Call
             }
         }
         {
-            typedef void (variable_editor::*_t)(const QString & );
-            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::selected_command_signal)) {
+            typedef void (variable_editor::*_t)(const fcn_callback & );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::interpreter_event)) {
                 *result = 10;
                 return;
             }
         }
+        {
+            typedef void (variable_editor::*_t)(const meth_callback & );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::interpreter_event)) {
+                *result = 11;
+                return;
+            }
+        }
     }
 }
 
@@ -1243,10 +1296,17 @@ void octave::variable_editor::delete_selected_signal()
 }
 
 // SIGNAL 10
-void octave::variable_editor::selected_command_signal(const QString & _t1)
+void octave::variable_editor::interpreter_event(const fcn_callback & _t1)
 {
     void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
     QMetaObject::activate(this, &staticMetaObject, 10, _a);
 }
+
+// SIGNAL 11
+void octave::variable_editor::interpreter_event(const meth_callback & _t1)
+{
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
+    QMetaObject::activate(this, &staticMetaObject, 11, _a);
+}
 QT_WARNING_POP
 QT_END_MOC_NAMESPACE
