@@ -2,18 +2,18 @@
 #  include "config.h"
 #endif
 /****************************************************************************
-** Meta object code from reading C++ file 'workspace-model.h'
+** Meta object code from reading C++ file 'moc-workspace-model.h'
 **
 ** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.i686/src/octave-5.1.0/libgui/src/workspace-model.h"
+#include "libgui/src/moc-workspace-model.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
-#error "The header file 'workspace-model.h' doesn't include <QObject>."
+#error "The header file 'moc-workspace-model.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 67
 #error "This file was generated using the moc from 5.9.4. It"
 #error "cannot be used with the include files from this version of Qt."
@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_octave__workspace_model_t {
-    QByteArrayData data[15];
-    char stringdata0[200];
+    QByteArrayData data[12];
+    char stringdata0[169];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -38,25 +38,21 @@ QT_MOC_LITERAL(0, 0, 23), // "octave::workspace_model"
 QT_MOC_LITERAL(1, 24, 13), // "model_changed"
 QT_MOC_LITERAL(2, 38, 0), // ""
 QT_MOC_LITERAL(3, 39, 22), // "prompt_variable_editor"
-QT_MOC_LITERAL(4, 62, 15), // "rename_variable"
-QT_MOC_LITERAL(5, 78, 8), // "old_name"
-QT_MOC_LITERAL(6, 87, 8), // "new_name"
-QT_MOC_LITERAL(7, 96, 13), // "set_workspace"
-QT_MOC_LITERAL(8, 110, 9), // "top_level"
-QT_MOC_LITERAL(9, 120, 5), // "debug"
-QT_MOC_LITERAL(10, 126, 16), // "symbol_info_list"
-QT_MOC_LITERAL(11, 143, 7), // "syminfo"
-QT_MOC_LITERAL(12, 151, 15), // "clear_workspace"
-QT_MOC_LITERAL(13, 167, 15), // "notice_settings"
-QT_MOC_LITERAL(14, 183, 16) // "const QSettings*"
+QT_MOC_LITERAL(4, 62, 13), // "set_workspace"
+QT_MOC_LITERAL(5, 76, 9), // "top_level"
+QT_MOC_LITERAL(6, 86, 5), // "debug"
+QT_MOC_LITERAL(7, 92, 16), // "symbol_info_list"
+QT_MOC_LITERAL(8, 109, 7), // "syminfo"
+QT_MOC_LITERAL(9, 117, 15), // "clear_workspace"
+QT_MOC_LITERAL(10, 133, 15), // "notice_settings"
+QT_MOC_LITERAL(11, 149, 19) // "const gui_settings*"
 
     },
     "octave::workspace_model\0model_changed\0"
-    "\0prompt_variable_editor\0rename_variable\0"
-    "old_name\0new_name\0set_workspace\0"
+    "\0prompt_variable_editor\0set_workspace\0"
     "top_level\0debug\0symbol_info_list\0"
     "syminfo\0clear_workspace\0notice_settings\0"
-    "const QSettings*"
+    "const gui_settings*"
 };
 #undef QT_MOC_LITERAL
 
@@ -66,32 +62,30 @@ static const uint qt_meta_data_octave__workspace_model[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-       6,   14, // methods
+       5,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
        0,       // flags
-       3,       // signalCount
+       2,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    0,   44,    2, 0x06 /* Public */,
-       3,    0,   45,    2, 0x06 /* Public */,
-       4,    2,   46,    2, 0x06 /* Public */,
+       1,    0,   39,    2, 0x06 /* Public */,
+       3,    0,   40,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-       7,    3,   51,    2, 0x0a /* Public */,
-      12,    0,   58,    2, 0x0a /* Public */,
-      13,    1,   59,    2, 0x0a /* Public */,
+       4,    3,   41,    2, 0x0a /* Public */,
+       9,    0,   48,    2, 0x0a /* Public */,
+      10,    1,   49,    2, 0x0a /* Public */,
 
  // signals: parameters
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::QString, QMetaType::QString,    5,    6,
 
  // slots: parameters
-    QMetaType::Void, QMetaType::Bool, QMetaType::Bool, 0x80000000 | 10,    8,    9,   11,
+    QMetaType::Void, QMetaType::Bool, QMetaType::Bool, 0x80000000 | 7,    5,    6,    8,
     QMetaType::Void,
-    QMetaType::Void, 0x80000000 | 14,    2,
+    QMetaType::Void, 0x80000000 | 11,    2,
 
        0        // eod
 };
@@ -104,10 +98,9 @@ void octave::workspace_model::qt_static_metacall(QObject *_o, QMetaObject::Call
         switch (_id) {
         case 0: _t->model_changed(); break;
         case 1: _t->prompt_variable_editor(); break;
-        case 2: _t->rename_variable((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
-        case 3: _t->set_workspace((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< const symbol_info_list(*)>(_a[3]))); break;
-        case 4: _t->clear_workspace(); break;
-        case 5: _t->notice_settings((*reinterpret_cast< const QSettings*(*)>(_a[1]))); break;
+        case 2: _t->set_workspace((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< const symbol_info_list(*)>(_a[3]))); break;
+        case 3: _t->clear_workspace(); break;
+        case 4: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -126,13 +119,6 @@ void octave::workspace_model::qt_static_metacall(QObject *_o, QMetaObject::Call
                 return;
             }
         }
-        {
-            typedef void (workspace_model::*_t)(const QString & , const QString & );
-            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&workspace_model::rename_variable)) {
-                *result = 2;
-                return;
-            }
-        }
     }
 }
 
@@ -161,13 +147,13 @@ int octave::workspace_model::qt_metacall(QMetaObject::Call _c, int _id, void **_
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 6)
+        if (_id < 5)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 6;
+        _id -= 5;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 6)
+        if (_id < 5)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 6;
+        _id -= 5;
     }
     return _id;
 }
@@ -183,12 +169,5 @@ void octave::workspace_model::prompt_variable_editor()
 {
     QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
 }
-
-// SIGNAL 2
-void octave::workspace_model::rename_variable(const QString & _t1, const QString & _t2)
-{
-    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
-    QMetaObject::activate(this, &staticMetaObject, 2, _a);
-}
 QT_WARNING_POP
 QT_END_MOC_NAMESPACE
